@@ -60,7 +60,11 @@ static int oauth_parse_str(char *params, zval *dest_array) /* {{{ */
 	}
 
 	res = params;
+#if PHP_VERSION_ID < 80500
 	separator = (char *) estrdup(PG(arg_separator).input);
+#else
+	separator = (char *) estrdup(ZSTR_VAL(PG(arg_separator).input));
+#endif
 	var = php_strtok_r(res, separator, &strtok_buf);
 	while (var) {
 		val = strchr(var, '=');
@@ -175,7 +179,7 @@ static void so_object_free_storage(zend_object *obj) /* {{{ */
 void soo_handle_error(php_so_object *soo, long errorCode, char *msg, char *response, char *additional_info) /* {{{ */
 {
 	zval ex;
-	zend_class_entry *dex = zend_exception_get_default(), *soox = soo_exception_ce;
+	zend_class_entry *dex = zend_ce_exception, *soox = soo_exception_ce;
 
 	object_init_ex(&ex, soox);
 
@@ -2786,7 +2790,7 @@ PHP_MINIT_FUNCTION(oauth)
 
 	INIT_CLASS_ENTRY(soo_ex_ce, "OAuthException", NULL);
 
-	soo_exception_ce = zend_register_internal_class_ex(&soo_ex_ce, zend_exception_get_default());
+	soo_exception_ce = zend_register_internal_class_ex(&soo_ex_ce, zend_ce_exception);
 #if PHP_VERSION_ID >= 80200
 	soo_exception_ce->ce_flags |= ZEND_ACC_ALLOW_DYNAMIC_PROPERTIES;
 	zend_string *attribute_name_AllowDynamicProperties_class_OAuthException = zend_string_init_interned("AllowDynamicProperties", sizeof("AllowDynamicProperties") - 1, 1);
